@@ -116,18 +116,24 @@ typedef int (wan_get_info_t)(char *, char **, off_t, int);
 	schedule_work(tq);
  }
 
+
  static inline int wan_task_dequeue(struct tq_struct *tq)
  {
-#if  LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+#if  LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,23)
 	return cancel_work_sync (tq);
+
+#elif defined(work_clear_pending)
+	return cancel_work_sync (tq);
+
+#elif defined(WORK_STRUCT_NOAUTOREL)
+	return 0;
 #else
 	int err;
 	err=cancel_delayed_work(tq);
 	flush_scheduled_work();
 	return err;
 #endif
- }
-
+ }           
 
 #define ADMIN_CHECK()  {if (!capable(CAP_SYS_ADMIN)) {\
                              if (WAN_NET_RATELIMIT()) { \
