@@ -817,11 +817,11 @@ static void wp_tdmv_report_alarms(void* pcard, unsigned long te_alarm)
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 					       	WAN_TE1_DDLB_MODE,
-					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+					       	WAN_TE1_LB_DISABLE);
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_LINELB_MODE,
-					       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
+					       	WAN_TE1_LB_ENABLE);
 				wp->span.maintstat = ZT_MAINT_REMOTELOOP;
 			}
 		}else{
@@ -834,11 +834,11 @@ static void wp_tdmv_report_alarms(void* pcard, unsigned long te_alarm)
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_DDLB_MODE,
-					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+					       	WAN_TE1_LB_DISABLE);
 				card->wandev.fe_iface.set_fe_lbmode(
 						&wp->card->fe,
 						WAN_TE1_LINELB_MODE,
-					       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+					       	WAN_TE1_LB_DISABLE);
 				wp->span.maintstat = ZT_MAINT_NONE;
 			}
 		}else{
@@ -1357,11 +1357,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_DDLB_MODE,
-				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_DISABLE);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_DISABLE);
 			break;
 	    	case ZT_MAINT_LOCALLOOP:
 			DEBUG_EVENT("%s: T1: Set to local loopback mode (local/no remote loop)\n",
@@ -1369,11 +1369,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_DISABLE);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_DDLB_MODE,
-				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_ENABLE);
 			break;
 	    	case ZT_MAINT_REMOTELOOP:
 			DEBUG_EVENT("%s: T1: Set to remote loopback mode (no local/remote loop)\n",
@@ -1381,11 +1381,11 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_ENABLE);
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_DISABLE);
 			break;
 	    	case ZT_MAINT_LOOPUP:
 			DEBUG_EVENT("%s: T1: Send loopup code\n",
@@ -1393,7 +1393,7 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_TX_LINELB_MODE,
-				       	WAN_TE1_LB_ENABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_ENABLE);
 			break;
 	    	case ZT_MAINT_LOOPDOWN:
 			DEBUG_EVENT("%s: T1: Send loopdown code\n",
@@ -1401,7 +1401,7 @@ static int wp_tdmv_maint(struct zt_span *span, int cmd)
 			card->wandev.fe_iface.set_fe_lbmode(
 					&wp->card->fe,
 					WAN_TE1_TX_LINELB_MODE,
-				       	WAN_TE1_LB_DISABLE,ENABLE_ALL_CHANNELS);
+				       	WAN_TE1_LB_DISABLE);
 			break;
 	    	case ZT_MAINT_LOOPSTOP:
 			DEBUG_EVENT("%s: T1: Stop sending loop code\n",
@@ -2001,7 +2001,7 @@ static int wp_tdmv_hwec_create(struct dahdi_chan *chan, struct dahdi_echocanpara
 {
 	wp_tdmv_softc_t	*wp = NULL;
 	sdla_t *card = NULL;
-	int	channel = chan->chanpos;
+	int	channel=0;
 	int	err = -EINVAL;
 
 	if (ecp->param_count > 0) {
@@ -2014,6 +2014,8 @@ static int wp_tdmv_hwec_create(struct dahdi_chan *chan, struct dahdi_echocanpara
 	wp = chan->pvt;
 	WAN_ASSERT2(wp->card == NULL, -ENODEV);
 	card = wp->card;
+	
+	channel = chan->chanpos;
 
 	if (!wp->ise1) {
 		channel--;
@@ -2054,7 +2056,7 @@ static void wp_tdmv_hwec_free(struct dahdi_chan *chan, struct dahdi_echocan_stat
 {
 	wp_tdmv_softc_t	*wp = NULL;
 	sdla_t *card = NULL;
-	int	channel = chan->chanpos;
+	int	channel;
 
 	memset(ec, 0, sizeof(*ec));
 
@@ -2064,6 +2066,7 @@ static void wp_tdmv_hwec_free(struct dahdi_chan *chan, struct dahdi_echocan_stat
 	if(wp->card == NULL) return;
 	card = wp->card;
 
+	channel = chan->chanpos;
 	wan_clear_bit(channel, &card->wandev.rtp_tap_call_map);
 
 	if (card->wandev.ec_enable) {
@@ -2092,7 +2095,7 @@ static int wp_tdmv_hwec(struct zt_chan *chan, int enable)
 {
 	wp_tdmv_softc_t *wp = NULL;
 	sdla_t      *card = NULL;
-	int     channel = chan->chanpos;
+	int     channel;
 	int     err = -EINVAL;
 
 	WAN_ASSERT2(chan == NULL, -ENODEV);
@@ -2101,6 +2104,7 @@ static int wp_tdmv_hwec(struct zt_chan *chan, int enable)
 	WAN_ASSERT2(wp->card == NULL, -ENODEV);
 	card = wp->card;
 
+	channel = chan->chanpos;
 	if (!wp->ise1){
 		channel--;
 	}
@@ -2652,6 +2656,11 @@ static void wp_tdmv_callback_dtmf (void* card_id, wan_event_t *event)
 
 	WAN_ASSERT1(wan_tdmv->sc == NULL);
 	wp = wan_tdmv->sc;
+
+	/* fechan check is a sanity check */
+	if (!wp->ise1 && fechan > 0){
+		fechan--;
+	}
 	
 	if (event->type != WAN_EVENT_EC_DTMF){
 		DEBUG_EVENT("ERROR: %s: Invalid event type %X!\n",
